# teensylogger_tk.py
# Gui class (module) for teensylogger

# www.weigu.lu/b/teensylogger

from Tkinter import *   # Python 3 "from tkinter import *"
import ttk              # Python 3 "from tkinter import ttk"
from teensylogger import *
from time import sleep, strftime
from datetime import datetime

class Tl_gui:
    def __init__(self, master, tl, tl_data_dir):
        self.tl = tl
        self.tl_data_dir = tl_data_dir
        self.tl_file_r = tl_data_dir + 'tl_data_'         # the data file
        self.tl_file_c = tl_data_dir + 'tl_rawdata_'      # the raw data file
        mainframe = ttk.Frame(master, padding="3 3 12 12")
        mainframe.grid(column=0, row=0, sticky=(N, W, E, S))
        # expanding window
        mainframe.columnconfigure(0, weight=10)
        mainframe.columnconfigure(1, weight=10)
        mainframe.columnconfigure(2, weight=10)
        mainframe.columnconfigure(3, weight=1)
        mainframe.rowconfigure(0, weight=1)
        mainframe.rowconfigure(1, weight=10)
        mainframe.rowconfigure(2, weight=1)
        mainframe.rowconfigure(3, weight=1)

        # get the existing serial ports
        portnames = tl.scan_serial()

        # Spinbox to chose serial port
        self.spinb1_var = StringVar()
        self.spinb1_var.set(self.tl.port)
        spinb1 = Spinbox(mainframe, values=portnames,
                         textvariable=self.spinb1_var, width=12)
        spinb1.grid(column=0, row=0, sticky=(N, W))

        textstr_df = 'Data files in:\n' + self.tl_data_dir
        label1 = ttk.Label(mainframe, text=textstr_df)
        label1.grid(column=2, row=0, sticky=(N, E))

        # Textbox + Scrollbar
        self.txt_win = Text(mainframe, state='normal', width=80, height=24)
        # wrap='none')
        self.txt_win.grid(columnspan=3, row=1, sticky=(N, W, E, S))
        scrollbar = ttk.Scrollbar(mainframe, orient=VERTICAL,
                                  command=self.txt_win.yview)
        scrollbar.grid(column=3, row=1, sticky=(N, S))
        self.txt_win.configure(yscrollcommand=scrollbar.set)

        # Buttons
        butt1 = ttk.Button(mainframe, text='Clear Textwindow',
                           command=self.clear_textwindow, width=20)
        butt1.grid(column=1, row=0, sticky=N)
        butt2 = ttk.Button(mainframe, text='Get minute data',
                           command=self.get_min, width=20)
        butt2.grid(column=0, row=2, sticky=W)
        butt3 = ttk.Button(mainframe, text='Get quarter data',
                           command=self.get_qua, width=20)
        butt3.grid(column=1, row=2, sticky=W + E)
        butt4 = ttk.Button(mainframe, text='Get day data',
                           command=self.get_day, width=20)
        butt4.grid(column=2, row=2, sticky=E)
        butt5 = ttk.Button(mainframe, text='Get 2 Pointer',
                           command=self.get_pointers, width=20)
        butt5.grid(column=0, row=3, sticky=W)
        butt6 = ttk.Button(mainframe, text='Get all quarter data',
                           command=self.get_all_qua, width=20)
        butt6.grid(column=1, row=3, sticky=W + E)
        butt7 = ttk.Button(mainframe, text='Get all day data',
                           command=self.get_all_day, width=20)
        butt7.grid(column=2, row=3, sticky=E)
        butt9 = ttk.Button(mainframe, text='Clear all data',
                           command=self.clear_data, width=20)
        butt9.grid(column=1, row=4, sticky=W + E)

        #Entry fields with buttons
        self.pointers = StringVar()
        self.date_time = StringVar()
        self.date_time.set(datetime.now().strftime('%d%m%y%H%M'))
        self.pointers.set('0000E000')
        p_entry = ttk.Entry(mainframe, width=20, textvariable=self.pointers)
        p_entry.grid(column=0, row=5, sticky=W)
        dt_entry = ttk.Entry(mainframe, width=20, textvariable=self.date_time)
        dt_entry.grid(column=2, row=5, sticky=E)

        butt8 = ttk.Button(mainframe, text='Set pointers',
                           command=self.set_pointers, width=20)
        butt8.grid(column=0, row=4, sticky=W)
        butt10 = ttk.Button(mainframe, text='Set date and time',
                            command=self.set_date_time,
                            width=20)
        butt10.grid(column=2, row=4, sticky=E)

        l2_text = 'quarter+day (HByte first)\n   example: 0000E000'
        label2 = ttk.Label(mainframe, width=20, anchor=CENTER,
                           text=l2_text)
        label2.grid(column=0, row=6, sticky=(W))
        l3_text = '    ddmmyyhhmm\nexample: 0101141200'
        label3 = ttk.Label(mainframe, width=20, anchor=CENTER,
                           text=l3_text)
        label3.grid(column=2, row=6, sticky=(E))

        # Padding
        for child in mainframe.winfo_children():
            child.grid_configure(padx=5, pady=5)

# feet_entry.focus()
# root.bind('<Return>', cal2)

    def clear_textwindow(self):
        self.txt_win.delete(1.0, END)

    def get_min(self):
        self.tl.port = self.spinb1_var.get()
        text1 = ('Datum   \tZeit    \tP1[W]\tP2[W]\tP3[W]\tP4[W]\tP5[W]\t' +
                 'P6 [W]\tP7 [W]\tP8 [W]\n')
        self.txt_win.insert(END, text1)
        str_txt = '\t'.join(self.tl.get_min(self.tl_file_r, self.tl_file_c))
        self.txt_win.insert(END, str_txt + '\n\n')

    def get_qua(self):
        self.tl.port = self.spinb1_var.get()
        text1 = ('Datum   \tZeit    \tE1[Wh]\tE2[Wh]\tE3[Wh]\tE4[Wh]\tE5[Wh]'
                 + '\tE6 [Wh]\tE7 [Wh]\tE8 [Wh]\n')
        self.txt_win.insert(END, text1)
        txtlist = self.tl.get_qua(self.tl_file_r, self.tl_file_c)
        if len(txtlist) == 1:
            self.txt_win.insert(END, txtlist[0] + '\n')
        else:
            for i in range(7):
                str_txt = '\t'.join(txtlist[0 + i * 10:10 + i * 10])
                self.txt_win.insert(END, str_txt)
        self.txt_win.insert(END, '\n')

    def get_day(self):
        self.tl.port = self.spinb1_var.get()
        text1 = ('Datum   \tZeit    \tE1[Wh]\tE2[Wh]\tE3[Wh]\tE4[Wh]\tE5[Wh]'
                 + '\tE6 [Wh]\tE7 [Wh]\tE8 [Wh]\n')
        self.txt_win.insert(END, text1)
        txtlist = self.tl.get_day(self.tl_file_r, self.tl_file_c)
        if len(txtlist) == 1:
            self.txt_win.insert(END, txtlist[0] + '\n')
        else:
            for i in range(7):
                str_txt = '\t'.join(txtlist[0 + i * 10:10 + i * 10])
                self.txt_win.insert(END, str_txt)
        self.txt_win.insert(END, '\n')

    def get_all_qua(self):
        self.tl.port = self.spinb1_var.get()
        text1 = ('please wait (max. 3 minutes!)\n')
        self.txt_win.insert(END, text1)
        self.txt_win.update_idletasks()     # force screen update
        text1 = ('Datum   \tZeit    \tE1[Wh]\tE2[Wh]\tE3[Wh]\tE4[Wh]\tE5[Wh]'
                 + '\tE6 [Wh]\tE7 [Wh]\tE8 [Wh]\n')
        self.txt_win.insert(END, text1)
        txtlist = self.tl.get_all_qua(self.tl_file_r, self.tl_file_c)
        if len(txtlist) == 1:
            self.txt_win.insert(END, txtlist[0] + '\n')
        else:
            for i in range(448 * 7):
                str_txt = '\t'.join(txtlist[0 + i * 10:10 + i * 10])
                self.txt_win.insert(END, str_txt)

    def get_all_day(self):
        self.tl.port = self.spinb1_var.get()
        text1 = ('please wait for about 30 seconds!!\n')
        self.txt_win.insert(END, text1)
        self.txt_win.update_idletasks()     # force screen update
        text1 = ('Datum   \tZeit    \tE1[Wh]\tE2[Wh]\tE3[Wh]\tE4[Wh]\tE5[Wh]'
                 + '\tE6 [Wh]\tE7 [Wh]\tE8 [Wh]\n')
        self.txt_win.insert(END, text1)
        txtlist = self.tl.get_all_day(self.tl_file_r, self.tl_file_c)
        for i in range(7):
            str_txt = '\t'.join(txtlist[0 + i * 10:10 + i * 10])
            self.txt_win.insert(END, str_txt)
        self.txt_win.insert(END, '\n')

    def get_pointers(self):
        self.tl.port = self.spinb1_var.get()
        text1 = ('quarter_pointer\tday_pointer\n')
        self.txt_win.insert(END, text1)
        str_txt = '\t\t'.join(self.tl.get_pointers())
        self.txt_win.insert(END, str_txt + '\n\n')

    def set_pointers(self):
        self.tl.port = self.spinb1_var.get()
        p_text = self.pointers.get()
        text1 = ('Sending the pointer addresses!\n')
        self.txt_win.insert(END, text1)
        self.txt_win.update_idletasks()     # force screen update
        p_text = self.pointers.get()
        str_txt = '\t'.join(self.tl.set_pointers(p_text))
        self.txt_win.insert(END, str_txt + '\n\n')

    def clear_data(self):
        self.tl.port = self.spinb1_var.get()
        text1 = ('please wait!!\n')
        self.txt_win.insert(END, text1)
        self.txt_win.update_idletasks()     # force screen update
        str_txt = '\t'.join(self.tl.clear_data())
        self.txt_win.insert(END, str_txt + '\n\n')

    def set_date_time(self):
        self.tl.port = self.spinb1_var.get()
        dt_text = self.date_time.get()
        text1 = ('Sending date and time!\n')
        self.txt_win.insert(END, text1)
        self.txt_win.update_idletasks()     # force screen update
        dt_text = self.date_time.get()
        str_txt = '\t'.join(self.tl.set_date_time(dt_text))
        self.txt_win.insert(END, str_txt + '\n\n')

